noalyss-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Noalyss-commit] [noalyss] branch devel updated: Http_Input type : accep


From: Dany De Bontridder
Subject: [Noalyss-commit] [noalyss] branch devel updated: Http_Input type : accept also text
Date: Thu, 25 Nov 2021 08:38:18 -0500

This is an automated email from the git hooks/post-receive script.

sparkyx pushed a commit to branch devel
in repository noalyss.

The following commit(s) were added to refs/heads/devel by this push:
     new d3afe85  Http_Input type : accept also text
d3afe85 is described below

commit d3afe85c25896dcb53934463e88f550037e04973
Author: sparkyx <danydb@noalyss.eu>
AuthorDate: Thu Nov 25 14:38:09 2021 +0100

    Http_Input type : accept also text
---
 include/lib/http_input.class.php | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/include/lib/http_input.class.php b/include/lib/http_input.class.php
index 47d98fb..cfbdf4c 100644
--- a/include/lib/http_input.class.php
+++ b/include/lib/http_input.class.php
@@ -73,7 +73,7 @@ class HttpInput
         /**
      *  \brief  Check the type of the value
      * @param $p_name name of the variable
      * @param $p_type type of the variable (number,string,date,array)
      * @throws Exception if the variable doesn't exist or type incorrect
      * @todo Add regex:pattern
      */
@@ -82,7 +82,7 @@ class HttpInput
         try
         {
             // no check on string
-            if ($p_type=="string")
+            if ($p_type=="string" || $p_type=="text")
             {
                 return;
             }
@@ -141,7 +141,7 @@ class HttpInput
     /**
      *  @brief  Retrieve from $this->array the variable
      * @param $p_name name of the variable
-     * @param $p_type type of the variable 
(number,string,date('dd.mm.yyyy'),array)
+     * @param $p_type type of the variable (number,string or 
text,date('dd.mm.yyyy'),array)
      * @param $p_default default value is variable
      * @throws Exception if invalid
@@ -73,7 +73,7 @@ class HttpInput
      *  \brief  Check the type of the value
      * @param $p_name name of the variable
-     * @param $p_type type of the variable (number,string,date,array)
+     * @param $p_type type of the variable (number,string,text,date,array)
      * @throws Exception if the variable doesn't exist or type incorrect
      * @todo Add regex:pattern
      * @see check_type



reply via email to

[Prev in Thread] Current Thread [Next in Thread]